package com.tongran.rocketmq.service;

import java.util.List;
import com.tongran.rocketmq.domain.RmTemplateSwitch;

/**
 * 交换机监控模板Service接口
 * 
 * @author tongran
 * @date 2025-09-09
 */
public interface IRmTemplateSwitchService 
{
    /**
     * 查询交换机监控模板
     * 
     * @param id 交换机监控模板主键
     * @return 交换机监控模板
     */
    public RmTemplateSwitch selectRmTemplateSwitchById(Long id);

    /**
     * 查询交换机监控模板列表
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 交换机监控模板集合
     */
    public List<RmTemplateSwitch> selectRmTemplateSwitchList(RmTemplateSwitch rmTemplateSwitch);

    /**
     * 新增交换机监控模板
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 结果
     */
    public int insertRmTemplateSwitch(RmTemplateSwitch rmTemplateSwitch);

    /**
     * 修改交换机监控模板
     * 
     * @param rmTemplateSwitch 交换机监控模板
     * @return 结果
     */
    public int updateRmTemplateSwitch(RmTemplateSwitch rmTemplateSwitch);

    /**
     * 批量删除交换机监控模板
     * 
     * @param ids 需要删除的交换机监控模板主键集合
     * @return 结果
     */
    public int deleteRmTemplateSwitchByIds(Long[] ids);

    /**
     * 删除交换机监控模板信息
     * 
     * @param id 交换机监控模板主键
     * @return 结果
     */
    public int deleteRmTemplateSwitchById(Long id);
}
