package com.tongran.rocketmq.controller;

import com.tongran.common.core.utils.poi.ExcelUtil;
import com.tongran.common.core.web.controller.BaseController;
import com.tongran.common.core.web.domain.AjaxResult;
import com.tongran.common.core.web.page.TableDataInfo;
import com.tongran.common.log.annotation.Log;
import com.tongran.common.log.enums.BusinessType;
import com.tongran.common.security.annotation.RequiresPermissions;
import com.tongran.rocketmq.domain.RmTemplateSwitch;
import com.tongran.rocketmq.service.IRmTemplateSwitchService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 交换机监控模板Controller
 * 
 * @author tongran
 * @date 2025-09-09
 */
@RestController
@RequestMapping("/switch")
@RequiresPermissions("rocketmq:switch")
public class RmTemplateSwitchController extends BaseController
{
    @Autowired
    private IRmTemplateSwitchService rmTemplateSwitchService;

    /**
     * 查询交换机监控模板列表
     */
    @GetMapping("/list")
    public TableDataInfo list(RmTemplateSwitch rmTemplateSwitch)
    {
        startPage();
        List<RmTemplateSwitch> list = rmTemplateSwitchService.selectRmTemplateSwitchList(rmTemplateSwitch);
        return getDataTable(list);
    }

    /**
     * 导出交换机监控模板列表
     */
    @Log(title = "交换机监控模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmTemplateSwitch rmTemplateSwitch)
    {
        List<RmTemplateSwitch> list = rmTemplateSwitchService.selectRmTemplateSwitchList(rmTemplateSwitch);
        ExcelUtil<RmTemplateSwitch> util = new ExcelUtil<RmTemplateSwitch>(RmTemplateSwitch.class);
        util.exportExcel(response, list, "交换机监控模板数据");
    }

    /**
     * 获取交换机监控模板详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmTemplateSwitchService.selectRmTemplateSwitchById(id));
    }

    /**
     * 新增交换机监控模板
     */
    @Log(title = "交换机监控模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmTemplateSwitch rmTemplateSwitch)
    {
        return toAjax(rmTemplateSwitchService.insertRmTemplateSwitch(rmTemplateSwitch));
    }

    /**
     * 修改交换机监控模板
     */
    @Log(title = "交换机监控模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmTemplateSwitch rmTemplateSwitch)
    {
        return toAjax(rmTemplateSwitchService.updateRmTemplateSwitch(rmTemplateSwitch));
    }

    /**
     * 删除交换机监控模板
     */
    @Log(title = "交换机监控模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmTemplateSwitchService.deleteRmTemplateSwitchByIds(ids));
    }
}
